@@ -76,7 +76,6 @@ namespace evalhyd
             xtl::xoptional<xt::xtensor<double, 5>, bool> itv_bnds;
             xtl::xoptional<xt::xtensor<double, 4>, bool> obs_in_itv;
             xtl::xoptional<xt::xtensor<double, 4>, bool> itv_width;
-            xtl::xoptional<xt::xtensor<double, 6>, bool> clim_bnds;
 
             // members for intermediate evaluation metrics
             // (i.e. before the reduction along the temporal axis)
@@ -124,9 +123,7 @@ namespace evalhyd
             xtl::xoptional<xt::xtensor<double, 5>, bool> CR;
             xtl::xoptional<xt::xtensor<double, 5>, bool> AW;
             xtl::xoptional<xt::xtensor<double, 5>, bool> AWN;
-            xtl::xoptional<xt::xtensor<double, 5>, bool> AWI;
             xtl::xoptional<xt::xtensor<double, 5>, bool> WS;
-            xtl::xoptional<xt::xtensor<double, 5>, bool> WSS;
             // > Multi-variate
             xtl::xoptional<xt::xtensor<double, 4>, bool> ES;
 
@@ -367,19 +364,6 @@ namespace evalhyd
                 return itv_width.value();
             };
 
-
-            xt::xtensor<double, 6> get_clim_bnds()
-            {
-                if (!clim_bnds.has_value())
-                {
-                    clim_bnds = elements::calc_clim_bnds(
-                            q_obs, get_c_lvl(), t_msk, b_exp,
-                            n_sit, n_ldt, n_itv, n_msk, n_exp
-                    );
-                }
-                return clim_bnds.value();
-            };
-
             // methods to compute intermediate metrics
             xt::xtensor<double, 4> get_bs()
             {
@@ -798,17 +782,6 @@ namespace evalhyd
                 return AWN.value();
             };
 
-            xt::xtensor<double, 5> get_AWI()
-            {
-                if (!AWI.has_value())
-                {
-                    AWI = metrics::calc_AWI(
-                            get_AW(), get_clim_bnds()
-                    );
-                }
-                return AWI.value();
-            };
-
             xt::xtensor<double, 5> get_WS()
             {
                 if (!WS.has_value())
@@ -821,18 +794,6 @@ namespace evalhyd
                 return WS.value();
             };
 
-            xt::xtensor<double, 5> get_WSS()
-            {
-                if (!WSS.has_value())
-                {
-                    WSS = metrics::calc_WSS(
-                            q_obs, get_c_lvl(), get_clim_bnds(), get_WS(),
-                            t_msk, b_exp, n_sit, n_ldt, n_itv, n_msk, n_exp
-                    );
-                }
-                return WSS.value();
-            };
-
             xt::xtensor<double, 4> get_ES()
             {
                 if (!ES.has_value())
