@@ -226,7 +226,7 @@ namespace evalhyd
             )
             {
                 // initialise output variable
-                xt::xtensor<double, 5> REL_DIAG =
+                xt::xtensor<double, 5> RANK_HIST =
                         xt::zeros<double>({n_sit, n_ldt, n_msk, n_exp, n_mbr + 1});
 
                 // compute variable one mask at a time to minimise memory imprint
@@ -246,7 +246,7 @@ namespace evalhyd
                         );
 
                         // compute the rank diagram
-                        xt::view(REL_DIAG, xt::all(), xt::all(), m, e, xt::all()) =
+                        xt::view(RANK_HIST, xt::all(), xt::all(), m, e, xt::all()) =
                                 xt::view(o_j, xt::all(), xt::all(),
                                          m, e, xt::all())
                                 / l
@@ -254,7 +254,7 @@ namespace evalhyd
                     }
                 }
 
-                return REL_DIAG;
+                return RANK_HIST;
             }
 
             /// Compute the Delta score.
@@ -449,4 +449,4 @@ namespace evalhyd
     }
 }
 
-#endif //EVALHYD_PROBABILIST_RANKS_HPP
\ No newline at end of file
+#endif //EVALHYD_PROBABILIST_RANKS_HPP
