@@ -210,19 +210,25 @@ namespace evalhyd
                     xtl::missing<const std::vector<std::string>>()
     )
     {
-        // check ranks of tensors
-        if (xt::get_rank<XD2>::value != 2)
+        // check ranks of expressions if they are tensors
+        if (xt::get_rank<XD2>::value != SIZE_MAX)
         {
-            throw std::runtime_error(
-                    "observations and/or predictions and/or thresholds "
-                    "are not two-dimensional"
-            );
+            if (xt::get_rank<XD2>::value != 2)
+            {
+                throw std::runtime_error(
+                        "observations and/or predictions and/or thresholds "
+                        "are not two-dimensional"
+                );
+            }
         }
-        if (xt::get_rank<XB3>::value != 3)
+        if (xt::get_rank<XB3>::value != SIZE_MAX)
         {
-            throw std::runtime_error(
-                    "temporal masks are not three-dimensional"
-            );
+            if (xt::get_rank<XB3>::value != 3)
+            {
+                throw std::runtime_error(
+                        "temporal masks are not three-dimensional"
+                );
+            }
         }
 
         // retrieve real types of the expressions
@@ -366,7 +372,7 @@ namespace evalhyd
             }
             else
             {
-                return XB3({});
+                return XB3(xt::zeros<bool>({0, 0, 0}));
             }
         };
         const XB3 c_msk = gen_msk();
