@@ -166,7 +166,7 @@ namespace evalhyd
     ///
     ///    .. code-block:: c++
     ///
-    ///       evalhyd::evalp(obs, prd, {"CRPS"});
+    ///       evalhyd::evalp(obs, prd, {"CRPS_FROM_QS"});
     ///
     /// \endrst
     template <class XD2, class XD4, class XB4 = xt::xtensor<bool, 4>,
@@ -190,24 +190,35 @@ namespace evalhyd
                     xtl::missing<const std::vector<std::string>>()
     )
     {
-        // check ranks of tensors
-        if (xt::get_rank<XD2>::value != 2)
+        // check ranks of expressions if they are tensors
+        if (xt::get_rank<XD2>::value != SIZE_MAX)
         {
-            throw std::runtime_error(
-                    "observations and/or thresholds are not two-dimensional"
-            );
+            if (xt::get_rank<XD2>::value != 2)
+            {
+                throw std::runtime_error(
+                        "observations and/or thresholds are not two-dimensional"
+                );
+            }
         }
-        if (xt::get_rank<XD4>::value != 4)
+
+        if (xt::get_rank<XD4>::value != SIZE_MAX)
         {
-            throw std::runtime_error(
-                    "predictions are not four-dimensional"
-            );
+            if (xt::get_rank<XD4>::value != 4)
+            {
+                throw std::runtime_error(
+                        "predictions are not four-dimensional"
+                );
+            }
         }
-        if (xt::get_rank<XB4>::value != 4)
+
+        if (xt::get_rank<XB4>::value != SIZE_MAX)
         {
-            throw std::runtime_error(
-                    "temporal masks are not four-dimensional"
-            );
+            if (xt::get_rank<XB4>::value != 4)
+            {
+                throw std::runtime_error(
+                        "temporal masks are not four-dimensional"
+                );
+            }
         }
 
         // retrieve real types of the expressions
@@ -229,7 +240,7 @@ namespace evalhyd
                  "QS", "CRPS_FROM_QS",
                  "POD", "POFD", "FAR", "CSI", "ROCSS",
                  "RANK_HIST", "DS", "AS",
-                 "CR", "AW", "AWN", "AWI", "WS", "WSS",
+                 "CR", "AW", "AWN", "WS",
                  "ES"}
         );
 
@@ -368,7 +379,7 @@ namespace evalhyd
             }
             else
             {
-                return XB4({});
+                return XB4(xt::zeros<bool>({0, 0, 0, 0}));
             }
         };
         const XB4 c_msk = gen_msk();
@@ -536,24 +547,12 @@ namespace evalhyd
                         uncertainty::summarise_p(evaluator.get_AWN(), summary)
                 );
             }
-            else if ( metric == "AWI" )
-            {
-                r.emplace_back(
-                        uncertainty::summarise_p(evaluator.get_AWI(), summary)
-                );
-            }
             else if ( metric == "WS" )
             {
                 r.emplace_back(
                         uncertainty::summarise_p(evaluator.get_WS(), summary)
                 );
             }
-            else if ( metric == "WSS" )
-            {
-                r.emplace_back(
-                        uncertainty::summarise_p(evaluator.get_WSS(), summary)
-                );
-            }
             else if ( metric == "ES" )
             {
                 r.emplace_back(
