@@ -35,7 +35,7 @@ std::vector<std::string> all_metrics_p = {
         "QS", "CRPS_FROM_QS",
         "POD", "POFD", "FAR", "CSI", "ROCSS",
         "RANK_HIST", "DS", "AS",
-        "CR", "AW", "AWN", "AWI", "WS", "WSS",
+        "CR", "AW", "AWN", "WS",
         "ES"
 };
 
@@ -263,7 +263,7 @@ TEST(ProbabilistTests, TestIntervals)
     auto expected = load_expected_p();
 
     // compute scores
-    std::vector<std::string> metrics = {"CR", "AW", "AWN", "AWI", "WS", "WSS"};
+    std::vector<std::string> metrics = {"CR", "AW", "AWN", "WS"};
 
     std::vector<xt::xarray<double>> results =
             evalhyd::evalp(
@@ -271,7 +271,7 @@ TEST(ProbabilistTests, TestIntervals)
                     xt::eval(xt::view(observed, xt::newaxis(), xt::all())),
                     // shape: (sites [1], lead times [1], members [m], time [t])
                     xt::eval(xt::view(predicted, xt::newaxis(), xt::newaxis(), xt::all(), xt::all())),
-                    {"CR", "AW", "AWN", "AWI", "WS", "WSS"},
+                    {"CR", "AW", "AWN", "WS"},
                     xt::xtensor<double, 2>({}),
                     "",  // events
                     {30., 80.}  // c_lvl
